import cnchar from 'cnchar'
import 'cnchar-order'
import 'cnchar-radical'
import 'cnchar-trad'

export function init (): void {
  document.querySelectorAll('[stroke-count]').forEach((element) => {
    if (element.classList.contains('is-initialized')) {
      return
    }

    const character = element.getAttribute('stroke-count')
    if (character === null) {
      throw new Error('unreachable, stroke-count was queried')
    }
    const fullCounts: number[] = cnchar
      .stroke(character, 'order', 'count') as number[]
    const radicals = cnchar.radical(character)
    if (fullCounts.length !== radicals.length) {
      throw new Error(
        `${fullCounts.length} from counts, but ${radicals.length} radicals`
      )
    }

    const countList = radicals
      .map((r, idx) => [r.radicalCount, fullCounts[idx]])
      .filter(([_, fullCount]) => Number.isFinite(fullCount))
      .map(([radicalCount, fullCount]) => {
        const extra = Math.max(0, fullCount - radicalCount)
        return `${radicalCount}+${extra}`
      }).join(', ')
    element.innerHTML = countList
    element.classList.add('is-initialized')
  })
}
